<?php

namespace FilterPlusPro\Base;

use FilterPlusPro\Utils\Singleton;

defined( 'ABSPATH' ) || exit;

/**
 * Enqueue all css and js file class
 */
class Enqueue {

    use Singleton;

    /**
     * Main calling function
     */
    public function init() {
        // backend asset
        add_action( 'admin_enqueue_scripts', [$this, 'admin_enqueue_assets'] );
        // frontend asset
        add_action( 'wp_enqueue_scripts', [$this, 'frontend_enqueue_assets'] );
        // enqueue editor css.
        add_action( 'elementor/editor/before_enqueue_styles', [$this, 'elementor_editor_css'] );
        // enqueue editor js.
        add_action( 'elementor/frontend/before_enqueue_scripts', [$this, 'elementor_js'] );
    }
  

    /**
     * all admin js files function
     */
    public function admin_get_scripts() {
        $script_arr =  array(
            'filter-plus-admin-pro'     => array(
                'src'     => \FilterPlusPro::assets_url() . 'js/admin-pro.js',
                'version' => \FilterPlusPro::get_version(),
                'deps'    => ['jquery'],
            ),
        );
        
        return $script_arr;
    }

    /**
     * all admin css files function
     *
     */
    public function admin_get_styles() {
        return array(
            'filter-plus-pro-admin' => array(
                'src'     => \FilterPlusPro::assets_url() . 'css/admin.css',
                'version' => \FilterPlusPro::get_version(),
            ),
        );
    }

    /**
     * Enqueue admin js and css function
     *
     * @param  $var
     */
    public function admin_enqueue_assets() {
        $screen = get_current_screen();
        $pages  = \FilterPlusPro\Utils\Helper::admin_pages_id();
        // load js in specific pages
        if ( is_admin() && ( in_array( $screen->id , $pages ) ) ) {

                foreach ( $this->admin_get_scripts() as $key => $value ) {
                    $deps       = !empty( $value['deps'] ) ? $value['deps'] : false;
                    $version    = !empty( $value['version'] ) ? $value['version'] : false;
                    wp_enqueue_script( $key, $value['src'], $deps, $version, true );
                }

                // css

                foreach ( $this->admin_get_styles() as $key => $value ) {
                    $deps       = isset( $value['deps'] ) ? $value['deps'] : false;
                    $version    = !empty( $value['version'] ) ? $value['version'] : false;
                    wp_enqueue_style( $key, $value['src'], $deps, $version, 'all' );
                }

                // localize for admin
                $form_data                          = array();
                $form_data['ajax_url']              = admin_url( 'admin-ajax.php' );
                
                wp_localize_script( 'filter-pro-data', 'pro_admin_data', [ $form_data ] );
        }

    }


    /**
     * all public js files function
     */
    public function frontend_get_scripts() {
        $script_arr = array(
            'public-pro'     => array(
                'src'     => \FilterPlusPro::assets_url() . 'js/public-pro.js',
                'version' => \FilterPlusPro::get_version(),
                'deps'    => ['jquery'],
            )
        );

        return $script_arr;
    }

    /**
     * all css files function
     */
    public function frontend_get_styles() {
        $enequeue =  array(
            'filter-pro-public' => array(
                'src'     => \FilterPlusPro::assets_url() . 'css/public.css',
                'version' => \FilterPlusPro::get_version(),
            ),
        );

        return $enequeue;
    }

    /**
     * Enqueue admin js and css function
     */
    public function frontend_enqueue_assets() {
        // js
        $scripts = $this->frontend_get_scripts();

        foreach ( $scripts as $key => $value ) {
            $deps       = isset( $value['deps'] ) ? $value['deps'] : false;
            $version    = !empty( $value['version'] ) ? $value['version'] : false;
            wp_enqueue_script( $key, $value['src'], $deps, $version, true );
        }

        // css
        $styles = $this->frontend_get_styles();

        foreach ( $styles as $key => $value ) {
            $deps = isset( $value['deps'] ) ? $value['deps'] : false;
            $version    = !empty( $value['version'] ) ? $value['version'] : false;
            wp_enqueue_style( $key, $value['src'], $deps, $version, 'all' );
        }


        // localize for frontend
        $form_data                        = array();
        $form_data['wpc_ajax_url']        = admin_url( 'admin-ajax.php' );

        wp_localize_script( 'filter-pro-js', 'pro_client_data', array( json_encode( $form_data ) ) ); 
    }

    /**
     * Elementor editor css loaded
     */
    public function elementor_editor_css() {
    }

    /**
     * Elementor js loaded
     */
    public function elementor_js() {
    }

}


