<?php

namespace FilterPlusPro\Core\Admin;

use FilterPlus;
use FilterPlusPro\Utils\Singleton;
use FilterPlusPro\Utils\Helper as Helper;
use FilterPlus\Utils\Helper as HelperFree;
/**
 * Base Class
 *
 * @since 1.0.0
 */
class OrderFilter {

    use Singleton;
    /**
     * Initialize all modules.
     *
     * @since 1.0.0
     *
     * @return void
     */
    public function init() {
        add_action( 'woocommerce_order_list_table_restrict_manage_orders', array( $this, 'custom_product_filter') );
        add_filter( 'woocommerce_shop_order_list_table_prepare_items_query_args', array( $this, 'filter_order_by_product_id') );
    }

    /**
     * Run filter query
     *
     * @param [type] $query
     */
    public function filter_order_by_product_id( $query ) {

        if ( $query['type'] !== 'shop_order' ) {
            return;
        }

        if ( isset( $_GET['by_product'] ) ) {
            $order_key = $this->get_order_id(intval($_GET['by_product']));
            if ( count($order_key) == 0) {
                $query['limit'] = 0;
            }else{
                $query['order_key'] = $order_key;
            }
        }
        if ( isset( $_GET['by_status'] ) ) {
            $query['status'] = $_GET['by_status'];
        }

        return $query;
        
    }

    /**
     * Show custom option markup
     *
     * @param [type] $post_type
     */
    public function custom_product_filter() {
        extract(Helper::instance()->get_settings());
        
        $screen = get_current_screen();
        if ( ! isset( $screen->post_type ) || 'shop_order' !== $screen->post_type ) {
            return;
        }

        if ( 'yes' == $woo_order_filter_product ) {
            $by_product = isset( $_REQUEST['by_product'] ) ? wc_clean( wp_unslash( $_REQUEST['by_product'] ) ) : '';
            $html       ='';
            $products= wc_get_products( array('limit'  => -1,'status' => 'publish'));
            $html .='<Select name="by_product"><option value="">' .esc_html__( 'Filter by Products','filter-plus-pro' ).'</option>';
            foreach( $products as $product ) : 
                $selected = $by_product == $product->get_id() ?  'selected' :'';
                $html    .= '<option '.$selected.' value="'.esc_attr( $product->get_id() ).'">'.esc_html( $product->get_name() ).'</option>';
            endforeach; 
            $html .= '</Select>';
    
            echo HelperFree::kses($html);
        }
        if ( 'yes' == $woo_order_filter_status ) {
            $by_status  = isset( $_REQUEST['by_status'] ) ? wc_clean( wp_unslash( $_REQUEST['by_status'] ) ) : '';
            $html       ='';
            $statuses   = wc_get_order_statuses();
            $html .='<Select name="by_status"><option value="">' .esc_html__( 'Filter by Order Status','filter-plus-pro' ).'</option>';
            foreach( $statuses as $key=>$status ) : 
                $selected = $by_status == $key ?  'selected' :'';
                $html    .= '<option '.$selected.' value="'.esc_attr( $key ).'">'.esc_html( $status ).'</option>';
            endforeach; 
            $html .= '</Select>';
    
            echo HelperFree::kses($html);
        }
    }

    /**
     * Query for order key
     *
     * @param [type] $product_id
     */
    private function get_order_id($product_id){
        global $wpdb;
        $order_keys = array();
        $order_ids = $wpdb->get_col( "
                SELECT DISTINCT woi.order_id
                FROM {$wpdb->prefix}woocommerce_order_itemmeta as woim, 
                    {$wpdb->prefix}woocommerce_order_items as woi, 
                    {$wpdb->prefix}posts as p
                WHERE  woi.order_item_id = woim.order_item_id
                AND woi.order_id = p.ID
                AND woim.meta_key IN ( '_product_id', '_variation_id' )
                AND woim.meta_value LIKE '$product_id'
                ORDER BY woi.order_item_id DESC"
        );
        
        foreach ($order_ids as $value) {
            $order  = wc_get_order($value);
            $key    = $order->get_order_key();
            array_push($order_keys,$key);
        }
               
        return $order_keys;
    }
}
    

