<?php
/**
 * Plugin Name:       Filter Plus Pro
 * Plugin URI:        https://woooplugin.com/filter-plus
 * Description:       Filter Plus is an Advanced Filter Plugin for WooCommerce that allows users to add multiple filters like filter by category, product search, etc.
 * Version:           1.0.18
 * Requires at least: 5.2
 * Requires PHP:      7.3
 * Author:            Woooplugin
 * Author URI:        https://woooplugin.com/
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       filter-plus-pro
 * Domain Path:       /languages
 * @package Filter Plus Pro
 * @category Core
 * @author Filter Plus Pro
 * @version 1.0.0
 */

 // Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * The Main Plugin Requirements Checker
 *
 * @since 1.0.0
 */
final class FilterPlusPro {

	private static $instance;

	/**
     * Current  Version
     *
     * @return string
     */
    public static function get_version() {
        return '1.0.18';
    }

	/**
     * Singleton Instance
     *
     * @return Filter Plus Pro
     */
    public static function get_instance() {
        if ( null === self::$instance ) {
            self::$instance = new self();
        }

        return self::$instance;
    }

	/**
     * Setup Plugin Requirements
     *
     * @since 1.0.0
     */
    private function __construct() {
        // Load modules
		add_action( 'plugins_loaded', array( $this, 'initialize_modules' ) , 9999 );
	}

	/**
	 * Initialize Modules
	 *
	 * @since 1.1.0
	 */
	public function initialize_modules() {
		$this->load_text_domain();
		do_action( 'filter-plus-pro/before_load' );
		require_once plugin_dir_path( __FILE__ ) . 'wrapper.php';
		// Load Plugin modules and classes
		\FilterPlusPro\Wrapper::instance()->init();

		do_action( 'filter-plus-pro/after_load' );

	}
	
	/**
     * Load Localization Files
     *
     * @since 1.0.0
     * @return void
     */
	public function load_text_domain() {
		load_plugin_textdomain( 'filter-plus-pro', false, self::plugin_dir() . 'languages/' );
    }

	/**
	 * Assets Directory Url
	 *
	 * @return void
	 */
	public static function assets_url() {
		return trailingslashit( self::plugin_url() . 'assets' );
	}

	/**
	 * Assets Folder Directory Path
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public static function assets_dir() {
		return trailingslashit( self::plugin_dir() . 'assets' );
	}

	/**
	 * Plugin Core File Directory Url
	 *
	 * @since 1.0.0
	 *
	 */
	public static function core_url() {
		return trailingslashit( self::plugin_url() . 'core' );
	}

	/**
	 * Plugin Lib File Directory Url
	 *
	 * @since 1.0.0
	 *	 */
	public static function lib_url() {
		return trailingslashit( self::plugin_url() . 'lib' );
	}

	/**
	 * Plugin Core File Directory Path
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public static function core_dir() {
		return trailingslashit( self::plugin_dir() . 'core' );
	}

	/**
	 * Plugin Url
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public static function plugin_url() {
		return trailingslashit( plugin_dir_url( self::plugin_file() ) );
	}

	/**
	 * Plugin Directory Path
	*
	* @since 1.0.0
	*
	* @return void
	*/
	public static function plugin_dir() {
		return trailingslashit( plugin_dir_path( self::plugin_file() ) );
	}

	/**
	 * Plugin Main File
	 *
	 * @return string
	 */
	public static function get_plugin_file() {
		return __FILE__;
	}

	/**
	 * Plugins Basename
	 *
	 * @since 1.0.0
	 */
	public static function plugins_basename(){
		return plugin_basename( self::plugin_file() );
	}

	/**
	 * Plugin File
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public static function plugin_file(){
		return __FILE__;
	}

}

// Initiate Plugin
FilterPlusPro::get_instance();

