<?php

namespace FilterPlusPro\Lib\License;

use FilterPlusPro\Utils\Singleton;

class License{

	use Singleton;
	
	/**
	 * Load license
	 */
	public function init() {
		// Register menu
		add_action( 'admin_menu', array( $this , 'register_license_menu' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'license_assets' ));

	}

	/**
	 * assets 
	 */
	public function license_assets() {
		$screen = get_current_screen();
        // load js in specific pages
        if ( is_admin() && $screen->id == 'filter-plus_page_filter-plus-license' ) {
			wp_enqueue_script( 
				'filter-plus-pro-license', 
				\FilterPlusPro::lib_url() . 'license/assets/js/license.js',
				['jquery'] , \FilterPlusPro::get_version() , true 
			);
			// localize for admin
			$form_data                          = array();
			$form_data['ajax_url']              = admin_url( 'admin-ajax.php' );
			$form_data['license_nonce']         = wp_create_nonce( 'license_nonce' );
			wp_localize_script( 'filter-plus-pro-license', 'license_obj', $form_data );
		}

	}

	public function register_license_menu() {
		add_submenu_page(
			'filter_plus',
			__( 'License', 'filter-plus-pro' ),
			__( 'License', 'filter-plus-pro' ),
			'manage_options',
			'filter-plus-license',
			array($this,'filter_plus_pro_license')
		);
	}

	public function filter_plus_pro_license() {
		require_once \FilterPlus::core_dir().'admin/header.php';
		$marketplace = array('woooplugin'=>'WoooPlugin');
		$license = \FilterPlusPro\Lib\License\Marketplace\License::instance();

		?>
		<div class="wrap">
			<h2 class="content-header mb-2"><?php esc_html_e('License', 'filter-plus-pro');?></h2>
		<form id="woooplugin-license" action="">
			<div class="license-wrapper">
				<div class="input-wrap">
					<label class="form-label"><?php esc_html_e('Select Marketplace', 'filter-plus-pro');?></label>
					<select class="input-section filter_plus_marketplace">
						<?php foreach($marketplace as $key=>$value):?>
						<option value="<?php echo esc_attr($key);?>"><?php echo esc_html($value);?></option>
						<?php endforeach;?>
					</select>
				</div>
				<?php $this->check_market_place($license); ?>
			</div>
			<?php if(empty($license) || (!empty($license) && $license->status() == 'invalid') ): ?>
			<button type="submit" class="button button-primary mt-2 submit_filter_license"><?php esc_html_e("Activate License","filter-plus-pro");?></button>
			<?php endif; ?>
			<div class="license_info"></div>
		</form>
		</div>
		<?php
	}

	public function check_market_place($license) {
		$this->woooplugin_filter_plus_pro($license);
	}
	public function woooplugin_filter_plus_pro($license){
		?>
		<div class="woooplugin">
			<?php if(empty($license) || (!empty($license) && $license->status() == 'invalid') ): ?>
				<div class="license-section">
					<label class="form-label"><?php esc_html_e('License Key', 'filter-plus-pro');?></label>
					<input type="text" name="woooplugin_license" class="license_input" id="license_key"
					placeholder="<?php esc_html_e("Please Enter Your License Key here","filter-plus-pro");?>"
					/>
				</div>
			<?php endif; ?>
			<?php $this->activated_license($license); ?>
		</div>
		<?php
	}

	public function activated_license($license) {
		?>
		<div class="activated_license">
			<?php
				if( $license->status() !== 'valid' ){
					?>
						<div class="license-content mt-1">
							<?php echo esc_html__( "Log in to your ", "filter-plus-pro" ); ?>
							<a href="https://woooplugin.com/purchase-history/" target="_blank"><?php echo esc_html__("Woooplugin Account", "filter-plus-pro"); ?></a>                                    
							<?php echo esc_html__("Copy the license key from your account and paste it below.", "filter-plus-pro");?>
							<a href="https://woooplugin.com/support/" target="_blank"><?php echo esc_html__("Support", "filter-plus-pro"); ?></a>
								
						</div>
					<?php
				} else {
					?>
					<div class="license-result">
						<p class="attr-alert attr-alert-success">
							<?php printf( esc_html__('Congratulations! Your product is activated for "%s"', 'filter-plus-pro'), parse_url(home_url(), PHP_URL_HOST)); ?>
							<a href="#" class='revoke-license'><?php echo esc_html__('Revoke License', 'filter-plus-pro');?></a>
						</p>
					</div>
					<?php
				}
			?>
		</div>
		<?php
	}
}
