<?php

namespace FilterPlusPro;

use FilterPlus\Utils\Helper;

require_once plugin_dir_path( __FILE__ ) . '/autoloader.php';
Class Wrapper{

	private static $instance;

	/**
	 * __construct function
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		// Load autoload method.
		Autoloader::run();
	}

	public function init() {
		// active free if not
		$this->prepare_filter_plus();
		if ( (!is_multisite()) || (is_multisite() && is_main_network() && is_main_site() && defined( 'MULTISITE' )) ) {
			$this->initialize_license_module();
		}
		
		// Core files
		\FilterPlusPro\Core\Core::instance()->init();
		// Enqueue Assets
		\FilterPlusPro\Base\Enqueue::instance()->init();
		// load license
		\FilterPlusPro\Lib\License\License::instance()->init();
	}

	public function initialize_license_module() {
		//fire up edd update module
		\FilterPlusPro\Lib\Updater\Init::instance()->init();

		//handle license notice
		//$this->manage_license_notice();
	}

	/**
	 * License active message
	 */
	public function manage_license_notice() {
                
        // Register license module
		$license = \FilterPlusPro\Lib\License\Marketplace\License::instance();
        $license->init();
		$selected_market_place  = 'woooplugin';
        if( $selected_market_place == "pluggable" ){
            return;
        }

        if ( $license->status() != 'valid' ) {
			Helper::push(
				[
					'id'          => 'filter-plus-pro-not-active',
					'type'        => 'error',
					'dismissible' => true,
					'btn'         => '',
					'message'     => sprintf( esc_html__( 'Please Active License for Filter Plus Pro to get all the pro features and update', 'filter-plus-pro' ) ),
				]
			);
        }
		return;
    }

	/**
	 * Prepare filter-plus free version if not activated
	 *
	 * @return void
	 */
	private function prepare_filter_plus() {
		// if filter-plus is not installed
		if ( ! did_action( 'filter-plus/before_load' ) ) {
			if ( \FilterPlusPro\Base\PluginActivator::instance()->make_dependency_ready() ) {
				// redirect to plugin dashboard
				wp_safe_redirect( "admin.php?page=filter_plus" );
			}
		}
	}

	public function filter_plus_notice() {
		$message = esc_html__( 'Filter Plus free  is required to run Pro version', 'filter-plus-pro' );
		
		return "<div id='error'><p>{$message}</p></div>";
	}

	/**
	 * Singleton Instance
	 *
	 * @return Bootstrap
	 */
	public static function instance() {

		if ( ! self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Product ID
	 */

	public function product_id() {
        return '5460';
    }

    public function store_url() {
        return 'https://woooplugin.com';
    }

    public function marketplace() {
        return 'woooplugin';
    }

    public function author_name() {
        return 'Woooplugin';
    }
}